Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/windirstat/llfio.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNiall Douglas (s [underscore] sourceforge {at} nedprod [dot] com) <spamtrap@nedprod.com>2018-07-11 11:54:13 +0300
committerNiall Douglas (s [underscore] sourceforge {at} nedprod [dot] com) <spamtrap@nedprod.com>2018-07-11 11:54:13 +0300
commitf3d672309a23a989f0c60aeccf309a8db670e719 (patch)
tree97fe3f5a2a174e04932a7e33b23afbf83b28fa48 /scripts
parent5021681a63ecb88f8fc583de0affd921b8677ecf (diff)
Finished renaming all AFIO => LLFIO, I think at least.
Diffstat (limited to 'scripts')
-rw-r--r--scripts/make_free_functions.py16
1 files changed, 8 insertions, 8 deletions
diff --git a/scripts/make_free_functions.py b/scripts/make_free_functions.py
index 6b2d6f1f..0368b261 100644
--- a/scripts/make_free_functions.py
+++ b/scripts/make_free_functions.py
@@ -1,5 +1,5 @@
#!/usr/bin/python
# Look for all static member functions marked AFIO_MAKE_FREE_FUNCTION and make them free
# (C) 2017 Niall Douglas
from __future__ import print_function
@@ -15,11 +15,11 @@ for header in glob.glob("../include/afio/*/*.hpp"):
for lineidx in range(0, len(lines)):
if lines[lineidx].startswith('class'):
current_class = lines[lineidx][6:lines[lineidx].find(':')]
- current_class = current_class.replace('AFIO_DECL', '').lstrip().rstrip()
- if 'AFIO_MAKE_FREE_FUNCTION' in lines[lineidx] and re.match('\s*AFIO_MAKE_FREE_FUNCTION', lines[lineidx]):
+ current_class = current_class.replace('LLFIO_DECL', '').lstrip().rstrip()
+ if 'LLFIO_MAKE_FREE_FUNCTION' in lines[lineidx] and re.match('\s*LLFIO_MAKE_FREE_FUNCTION', lines[lineidx]):
function = ''
for n in range(1, 100):
- if 'AFIO_REQUIRES' in lines[lineidx+n]:
+ if 'LLFIO_REQUIRES' in lines[lineidx+n]:
continue
function += lines[lineidx+n]
if lineidx+n+1 >= len(lines):
@@ -47,9 +47,9 @@ for header in glob.glob("../include/afio/*/*.hpp"):
if functions_to_be_freed_begin != -1:
del lines[functions_to_be_freed_begin+1:functions_to_be_freed_end]
else:
# Place just before the last AFIO_V2_NAMESPACE_END
functions_to_be_freed_begin = len(lines)-1
- while not lines[functions_to_be_freed_begin].startswith('AFIO_V2_NAMESPACE_END'):
+ while not lines[functions_to_be_freed_begin].startswith('LLFIO_V2_NAMESPACE_END'):
functions_to_be_freed_begin = functions_to_be_freed_begin - 1
lines.insert(functions_to_be_freed_begin, '// END make_free_functions.py\n\n')
lines.insert(functions_to_be_freed_begin, '// BEGIN make_free_functions.py\n')
@@ -58,8 +58,8 @@ for header in glob.glob("../include/afio/*/*.hpp"):
print((classname, function))
function = function.replace('virtual ', '')
function = function.replace('override', '')
- function = function.replace('AFIO_HEADERS_ONLY_MEMFUNC_SPEC ', '')
- function = function.replace('AFIO_HEADERS_ONLY_VIRTUAL_SPEC ', '')
+ function = function.replace('LLFIO_HEADERS_ONLY_MEMFUNC_SPEC ', '')
+ function = function.replace('LLFIO_HEADERS_ONLY_VIRTUAL_SPEC ', '')
completion_template = 'template <class CompletionRoutine>' in function
function = function.replace('template <class CompletionRoutine> ', '')
is_static = 'static ' in function
@@ -1,5 +1,5 @@
#!/usr/bin/python
-# Look for all static member functions marked AFIO_MAKE_FREE_FUNCTION and make them free
+# Look for all static member functions marked LLFIO_MAKE_FREE_FUNCTION and make them free
# (C) 2017 Niall Douglas
from __future__ import print_function
@@ -47,9 +47,9 @@ for header in glob.glob("../include/afio/*/*.hpp"):
del lines[functions_to_be_freed_begin+1:functions_to_be_freed_end]
else:
- # Place just before the last AFIO_V2_NAMESPACE_END
+ # Place just before the last LLFIO_V2_NAMESPACE_END
functions_to_be_freed_begin = len(lines)-1